==> libmspub-0.0.0.tar.bz2: libmspub-0.0.0/src/lib/EscherContainerType.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* libmspub
 * Version: MPL 1.1 / GPLv2+ / LGPLv2+
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License or as specified alternatively below. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Major Contributor(s):
 * Copyright (C) 2012 Brennan Vincent <brennanv@email.arizona.edu>
 *
 * All Rights Reserved.
 *
 * For minor contributions see the git repository.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPLv2+"), or
 * the GNU Lesser General Public License Version 2 or later (the "LGPLv2+"),
 * in which case the provisions of the GPLv2+ or the LGPLv2+ are applicable
 * instead of those above.
 */

#ifndef __ESCHERCONTAINERTYPE_H__
#define __ESCHERCONTAINERTYPE_H__

#define OFFICE_ART_DGG_CONTAINER      0xF000
#define OFFICE_ART_B_STORE_CONTAINER  0xF001
#define OFFICE_ART_DG_CONTAINER       0xF002
#define OFFICE_ART_SPGR_CONTAINER     0xF003
#define OFFICE_ART_SP_CONTAINER       0xF004
#define OFFICE_ART_CLIENT_DATA        0xF011
#define OFFICE_ART_CLIENT_ANCHOR      0xF010
#define OFFICE_ART_BLIP_PNG           0xF01E
#define OFFICE_ART_BLIP_JPEG          0xF01D
#define OFFICE_ART_BLIP_DIB           0xF01F
#define OFFICE_ART_BLIP_EMF           0xF01A
#define OFFICE_ART_BLIP_WMF           0xF01B
#define OFFICE_ART_BLIP_PICT          0xF01C
#define OFFICE_ART_BLIP_TIFF          0xF020
#define OFFICE_ART_FOPT               0xF00B
#define OFFICE_ART_FSP                0xF00A

#endif /* __ESCHERCONTAINERTYPE_H__ */
/* vim:set shiftwidth=2 softtabstop=2 expandtab: */

==> libmspub_0.0.6.orig.tar.bz2: libmspub-0.0.6/src/lib/EscherContainerType.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* libmspub
 * Version: MPL 1.1 / GPLv2+ / LGPLv2+
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License or as specified alternatively below. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Major Contributor(s):
 * Copyright (C) 2012 Brennan Vincent <brennanv@email.arizona.edu>
 *
 * All Rights Reserved.
 *
 * For minor contributions see the git repository.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPLv2+"), or
 * the GNU Lesser General Public License Version 2 or later (the "LGPLv2+"),
 * in which case the provisions of the GPLv2+ or the LGPLv2+ are applicable
 * instead of those above.
 */

#ifndef __ESCHERCONTAINERTYPE_H__
#define __ESCHERCONTAINERTYPE_H__

#define OFFICE_ART_DGG_CONTAINER      0xF000
#define OFFICE_ART_B_STORE_CONTAINER  0xF001
#define OFFICE_ART_DG_CONTAINER       0xF002
#define OFFICE_ART_SPGR_CONTAINER     0xF003
#define OFFICE_ART_SP_CONTAINER       0xF004
#define OFFICE_ART_CLIENT_DATA        0xF011
#define OFFICE_ART_CLIENT_ANCHOR      0xF010
#define OFFICE_ART_BLIP_PNG           0xF01E
#define OFFICE_ART_BLIP_JPEG          0xF01D
#define OFFICE_ART_BLIP_JPEGCMYK      0xF02A
#define OFFICE_ART_BLIP_DIB           0xF01F
#define OFFICE_ART_BLIP_EMF           0xF01A
#define OFFICE_ART_BLIP_WMF           0xF01B
#define OFFICE_ART_BLIP_PICT          0xF01C
#define OFFICE_ART_BLIP_TIFF          0xF029
#define OFFICE_ART_FOPT               0xF00B
#define OFFICE_ART_TERTIARY_FOPT      0xF122
#define OFFICE_ART_FSP                0xF00A
#define OFFICE_ART_FSPGR              0xF009
#define OFFICE_ART_CHILD_ANCHOR       0xF00F

#endif /* __ESCHERCONTAINERTYPE_H__ */
/* vim:set shiftwidth=2 softtabstop=2 expandtab: */
